@@ -78,8 +78,11 @@ public:
     void updateJustification(const std::string& justification) { _justification = justification; }
     void updateJustification(const Gtk::TextIter& textIter);
 
-    int getOffset() { return _charOffset; }
-    const std::string& getJustification() { return _justification; }
+    int getOffset() const { return _charOffset; }
+    const std::string& getJustification() const { return _justification; }
+
+    bool operator<(const CtAnchoredWidget &other) { return getOffset() < other.getOffset(); }
+    bool operator>(const CtAnchoredWidget &other) { return getOffset() > other.getOffset(); }
 
 protected:
     CtMainWin* _pCtMainWin;
@@ -126,6 +129,7 @@ public:
     void cursor_and_tooltips_handler(int x, int y);
     void zoom_text(const bool is_increase, const std::string& syntaxHighlighting);
     void set_spell_check(bool allow_on);
+    void synch_spell_check_change_from_gspell_right_click_menu();
 
     void set_buffer(const Glib::RefPtr<Gtk::TextBuffer>& buffer);
     void selection_update() {
